==> qt-creator-opensource-src-4.0.1.zip: qt-creator-opensource-src-4.0.1/src/libs/modelinglib/qmt/diagram_scene/capabilities/selectable.h <==
/****************************************************************************
**
** Copyright (C) 2016 Jochen Becher
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#ifndef QMT_SELECTABLE_H
#define QMT_SELECTABLE_H

namespace qmt {

class ISelectable
{
public:
    virtual ~ISelectable() { }

    virtual bool isSecondarySelected() const = 0;
    virtual void setSecondarySelected(bool secondarySelected) = 0;
    virtual bool isFocusSelected() const = 0;
    virtual void setFocusSelected(bool focusSelected) = 0;
};

} // namespace qmt

#endif // QMT_SELECTABLE_H

==> qt-creator-opensource-src-5.0.3.zip: qt-creator-opensource-src-5.0.3/src/libs/modelinglib/qmt/diagram_scene/capabilities/selectable.h <==
/****************************************************************************
**
** Copyright (C) 2016 Jochen Becher
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <QRectF>

namespace qmt {

class ISelectable
{
public:
    virtual ~ISelectable() { }

    virtual bool isSecondarySelected() const = 0;
    virtual void setSecondarySelected(bool secondarySelected) = 0;
    virtual bool isFocusSelected() const = 0;
    virtual void setFocusSelected(bool focusSelected) = 0;
    virtual QRectF getSecondarySelectionBoundary() = 0;
    virtual void setBoundarySelected(const QRectF &boundary, bool secondary) = 0;
};

} // namespace qmt
